@@ -1,9 +1,9 @@
 import os
-from .borg_thread import BorgThread
-from vorta.models import SettingsModel
+from .borg_job import BorgJob
+from vorta.store.models import SettingsModel
 
 
-class BorgMountThread(BorgThread):
+class BorgMountJob(BorgJob):
 
     def started_event(self):
         self.updated.emit(self.tr('Mounting archive into folder...'))
