@@ -1,6 +1,6 @@
 import peewee
 from .abc import VortaKeyring
-from vorta.models import SettingsModel
+from vorta.store.models import SettingsModel
 
 
 class VortaDBKeyring(VortaKeyring):
@@ -11,7 +11,7 @@ class VortaDBKeyring(VortaKeyring):
     """
 
     def set_password(self, service, repo_url, password):
-        from vorta.models import RepoPassword
+        from vorta.store.models import RepoPassword
         keyring_entry, created = RepoPassword.get_or_create(
             url=repo_url,
             defaults={'password': password}
@@ -20,7 +20,7 @@ class VortaDBKeyring(VortaKeyring):
         keyring_entry.save()
 
     def get_password(self, service, repo_url):
-        from vorta.models import RepoPassword
+        from vorta.store.models import RepoPassword
         try:
             keyring_entry = RepoPassword.get(url=repo_url)
             return keyring_entry.password
